package com.eitc.patient.controller;

import com.eitc.common.annotation.Log;
import com.eitc.common.core.controller.BaseController;
import com.eitc.common.core.domain.AjaxResult;
import com.eitc.common.enums.BusinessType;
import com.eitc.patient.domain.AppUser;
import com.eitc.patient.service.IAppUserService;
import com.eitc.patient.service.IClinicInfoService;
import com.eitc.patient.vo.ClinicInfoVO;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import javax.annotation.Resource;
import javax.validation.Valid;

/**
 * ApiController
 *
 * @author mtx
 * @date: 2024/06/20 8:37
 */
@Api(tags = "API接口")
@RestController
@RequestMapping("/app/api")
public class ApiAppController extends BaseController {

    @Resource
    private IAppUserService appUserService;
    @Resource
    private IClinicInfoService clinicInfoService;

    /**
     * APP切换诊所时同步数据
     *
     * @param beforeAppUser 前一次登录用户信息
     * @return 返回结果
     * @author mtx
     * @date: 2024/6/18 14:27
     */
    @GetMapping("/synchronizeData")
    @ApiOperation("APP切换诊所时同步数据")
    public AjaxResult synchronizeData(AppUser beforeAppUser) {
        return appUserService.synchronizeData(beforeAppUser);
    }

    /**
     * 新增门诊信息
     */
    @Log(title = "新增门诊信息", businessType = BusinessType.INSERT)
    @PostMapping
    @ApiOperation("新增门诊信息")
    public AjaxResult add(@ApiParam(name = "clinicInfo") @Valid @RequestBody ClinicInfoVO clinicInfo) {
        return clinicInfoService.addOrUpdate(clinicInfo);
    }
}
